/*
 * @Author: fxs bjnsfxs@163.com
 * @Date: 2024-08-20 17:56:13
 * @LastEditors: fxs bjnsfxs@163.com
 * @LastEditTime: 2024-12-03
 * @FilePath: \Game-Backstage-Management-System\src\types\table.ts
 * @Description:
 *
 */
import type { ReqConfig } from './dataAnalysis'
import type { ValueTypes } from './form'
import type { SpecialEffect } from './tableText'

// import type { EChartsOption } from 'echarts/types/dist/shared'

// 颜色类型
// export enum ColorType {
//   PRIMARY = 'primary',
//   SUCCESS = 'success',
//   INFO = 'info',
//   WARNING = 'warning',
//   DANGER = 'danger'
// }

// export interface GameTableData {
//   gameName: string //游戏名称
//   gid: string //游戏ID
//   ttAppid: string //游戏 tt 平台id
//   ttSecret: string //游戏 tt 平台密钥
//   wxAppid: string //游戏 微信平台 id
//   wxSecret: string // 游戏 微信 平台密钥
// }

// 表格分页的数据类型
export interface TablePaginationSetting {
  limit: number // 每页展示个数
  currentPage: number // 当前页码
  total: number // 数据总数
  pageSizeList: Array<number> // 页数大小列表
}

// 表格信息过滤时，需要用到的过滤类型
export enum FilterType {
  INPUT = 'input',
  SELECT = 'select',
  MULTI_SELECT = 'multiSelect',
  DATE = 'date',
  CUSTOM = 'custom'
}

// 筛选信息的格式
export interface QueryInfo {
  name: string
  label: string

  type: FilterType
  placeholder: string
  /**
   * 对此项的补充信息
   */
  supplementInfo?: string
  valueType?: ValueTypes
  otherOption?: any
  default?: any
  clearable?: boolean
}

// 表格字段信息格式
export interface TableFieldInfo {
  name: string
  cnName: string
  isShow: boolean
  needSort: boolean
  specialEffect?: SpecialEffect
}

// 表格工具栏的配置
export interface TableToolsConfig {
  add?: boolean
  download?: boolean
  headerMap?: Record<string, string>
  refresh?: boolean
  filterFields?: boolean
}

/**
 * 表格组件的属性
 */
export interface PropsParams {
  loadingState?: boolean // 外部控制表格加载状态
  needRowindex?: boolean // 是否需要行号
  needAverage?: boolean // 是否需要均值功能
  needTotal?: boolean // 是否需要总计
  needExpand?: boolean // 是否需要展开功能
  expandConfig?: {
    expandReqConfig: ReqConfig // 展开数据请求配置
    expandField: Array<TableFieldInfo> // 展开字段
  } // 展开配置
  // needChart?: boolean // 是否需要图表功能
  // chartOptions?: EChartsOption // 图表配置
  totalFunc?: (data: any, total: number) => any[] // 计算总计的函数
  openFilterQuery?: boolean // 是否开启上方查询功能,关闭后queryInfo无效
  queryInfo?: Array<QueryInfo> // 上方查询功能所需要的信息

  openPageQuery?: boolean // 是否开启分页功能，也就是下方的分页组件。关闭后，paginationConfig无效
  paginationConfig?: TablePaginationSetting // 表格分页的信息

  requestConfig?: ReqConfig // 请求配置，开启请求远程数据则该配置必填
  /**
   * 是否开启远程查询
   *
   * 启用此配置，则需要同时传入requestConfig，否则无效
   * 关闭配置则使用前端查询
   *
   */
  openRemoteQuery?: boolean

  /**
   * 是否开启远程数据源，开启后，会使用requestConfig中的url进行请求，并且忽略dataList的数据
   * 如果关闭该配置且不传入dataList，则表格将不会显示任何数据
   *
   * 开启此配置，将默认使用远程查询
   *
   */
  openRemoteReqData?: boolean

  /**
   * 直接传入的表格的数据源
   *
   * 当传入此配置，且没有开启openRemoteReqData，则会使用传入的数据源
   * 同时进行查询时，也会使用前端查询
   */
  dataList?: Array<any>

  tableFieldsInfo: Array<TableFieldInfo> // 表格字段信息
  /**
   *  工具栏配置
   *  如果需要控制字段的展示与否，请把tableFieldsInfo设置为响应式对象
   */
  tools?: TableToolsConfig
}

// 选择下拉框的信息格式
export interface SelectInfo {
  name: string
  cnName: string
  value: any
}

// 对话框设置
export interface DialogSetting {
  dialogVisible: boolean
  title: string
  formLabelWidth: string
  type: number // 0 是新增 1是修改
}
